@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2014 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -52,6 +52,7 @@ package com.openexchange.drive.json.action;
 import java.net.InetAddress;
 import java.net.UnknownHostException;
 import java.util.Arrays;
+import java.util.Locale;
 import javax.servlet.http.HttpServletRequest;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
@@ -67,6 +68,7 @@ import com.openexchange.drive.json.json.DriveFieldMapper;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.notify.hostname.HostData;
 import com.openexchange.groupware.notify.hostname.HostnameService;
+import com.openexchange.i18n.LocaleTools;
 import com.openexchange.java.Strings;
 import com.openexchange.tools.servlet.AjaxExceptionCodes;
 import com.openexchange.tools.servlet.CountingHttpServletRequest;
@@ -113,7 +115,7 @@ public abstract class AbstractDriveAction implements AJAXActionService {
         }
         int apiVersion = requestData.containsParameter("apiVersion") ? requestData.getParameter("apiVersion", Integer.class).intValue() : 0;
         DefaultDriveSession driveSession = new DefaultDriveSession(
-            session, rootFolderID, extractHostData(requestData, session), apiVersion, extractClientVersion(requestData));
+            session, rootFolderID, extractHostData(requestData, session), apiVersion, extractClientVersion(requestData), extractLocale(requestData));
         /*
          * extract device name information if present
          */
@@ -169,6 +171,23 @@ public abstract class AbstractDriveAction implements AJAXActionService {
         }
     }
 
+    /**
+     * Extracts a possible set locale override from the supplied request data.
+     *
+     * @param requestData The request data
+     * @return The locale, or <code>null</code> if not set
+     */
+    private static Locale extractLocale(AJAXRequestData requestData) {
+        Locale localeOverride = null;
+        if (requestData.containsParameter("locale")) {
+            localeOverride = LocaleTools.getLocale(requestData.getParameter("locale"));
+        }
+        if (null == localeOverride && requestData.containsParameter("language")) {
+            localeOverride = LocaleTools.getLocale(requestData.getParameter("language"));
+        }
+        return localeOverride;
+    }
+
     /**
      * Extracts host data from the supplied request and session.
      *
