@@ -8,7 +8,7 @@
  *
  *    In some countries OX, OX Open-Xchange, open xchange and OXtender
  *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the Open-Xchange, Inc. group of companies.
+ *    trademarks of the OX Software GmbH group of companies.
  *    The use of the Logos is not covered by the GNU General Public License.
  *    Instead, you are allowed to use these Logos according to the terms and
  *    conditions of the Creative Commons License, Version 2.5, Attribution,
@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2013 Open-Xchange, Inc.
+ *     Copyright (C) 2016-2020 OX Software GmbH
  *     Mail: info@open-xchange.com
  *
  *
@@ -74,6 +74,7 @@ public class DefaultDriveSession implements DriveSession {
     private final HostData hostData;
     private final DriveClientVersion clientVersion;
     private String deviceName;
+    private final Locale localeOverride;
     private Boolean diagnostics;
     private List<DriveFileField> fields;
     private List<FilePattern> fileExclusions;
@@ -87,14 +88,16 @@ public class DefaultDriveSession implements DriveSession {
      * @param hostData The host data as extracted from the corresponding http request
      * @param apiVersion The API version as set by the client, or <code>0</code> if not set
      * @param clientVersion The client version as set by the client, or {@link DriveClientVersion#VERSION_0} if not set
+     * @param localeOverride The locale string if overridden by client, or <code>null</code> to fall back to the user's locale
      */
-    public DefaultDriveSession(ServerSession session, String rootFolderID, HostData hostData, int apiVersion, DriveClientVersion clientVersion) {
+    public DefaultDriveSession(ServerSession session, String rootFolderID, HostData hostData, int apiVersion, DriveClientVersion clientVersion, Locale localeOverride) {
         super();
         this.session = session;
         this.rootFolderID = rootFolderID;
         this.hostData = hostData;
         this.apiVersion = apiVersion;
         this.clientVersion = clientVersion;
+        this.localeOverride = localeOverride;
     }
 
     /**
@@ -164,6 +167,9 @@ public class DefaultDriveSession implements DriveSession {
 
     @Override
     public Locale getLocale() {
+        if (null != localeOverride) {
+            return localeOverride;
+        }
         Locale locale = null;
         if (null != session) {
             User user = session.getUser();
