@@ -73,6 +73,7 @@ import com.openexchange.file.storage.FileStorageFolder;
 import com.openexchange.file.storage.composition.FileID;
 import com.openexchange.file.storage.composition.FolderID;
 import com.openexchange.java.Strings;
+import com.openexchange.mail.mime.ContentType;
 import com.openexchange.quota.QuotaExceptionCodes;
 
 /**
@@ -284,7 +285,7 @@ public class DriveUtils {
      */
     public static boolean indicatesFailedSave(OXException e) {
         return "IFO-0100".equals(e.getErrorCode()) || "IFO-2103".equals(e.getErrorCode()) ||
-            "FLD-0092".equals(e.getErrorCode()) || "FLD-0064".equals(e.getErrorCode());
+            "FLD-0092".equals(e.getErrorCode()) || "FLD-0064".equals(e.getErrorCode())|| FileStorageExceptionCodes.DENIED_MIME_TYPE.equals(e);
     }
 
     /**
@@ -326,8 +327,30 @@ public class DriveUtils {
         return fileNames;
     }
 
+    /**
+     * Checks that a (client-supplied) content type is allowed, throwing an appropriate exception in case validation is not passed.
+     * 
+     * @param contentType The content type to check
+     * @return The checked content type string
+     * @throws OXException {@link FileStorageExceptionCodes#DENIED_MIME_TYPE} if content type validation fails
+     */
+    public static String checkContentType(String contentType) throws OXException {
+        if (Strings.isEmpty(contentType)) {
+            return null;
+        }
+        ContentType checkdContentType;
+        try {
+            checkdContentType = new ContentType(contentType, true);
+        } catch (Exception e) {
+            throw FileStorageExceptionCodes.DENIED_MIME_TYPE.create(e); // MIME type could not be safely parsed
+        }
+        if (checkdContentType.contains("multipart/") || checkdContentType.containsBoundaryParameter()) {
+            throw FileStorageExceptionCodes.DENIED_MIME_TYPE.create(); // deny weird MIME types
+        }
+        return checkdContentType.toString();
+    }
+
     private DriveUtils() {
         super();
     }
-
 }
